PAWpySeed: pawpyseed.core.utils.PAWpyError Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.core.utils.PAWpyError Class Reference
Inheritance diagram for pawpyseed.core.utils.PAWpyError:
[legend]
Collaboration diagram for pawpyseed.core.utils.PAWpyError:
[legend]

## Public Member Functions
def | __init__ (self, msg)

## Public Attributes
| msg

## Detailed Description

    Class for handling errors that occur during execution
    of Python functions in pawpyseed

## Constructor & Destructor Documentation

def pawpyseed.core.utils.PAWpyError.__init__ | ( |  | self,
|  |  | msg
| ) |  |

## Member Data Documentation

pawpyseed.core.utils.PAWpyError.msg

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.py